==================================================================
demuxEM for demultiplexing cell/nucleus hashing single-cell data
==================================================================

|PyPI| |Conda| |Python| |License| |Docs|

.. |PyPI| image:: https://img.shields.io/pypi/v/demuxEM.svg
   :target: https://pypi.org/project/demuxEM

.. |Conda| image:: https://img.shields.io/conda/v/bioconda/demuxem
   :target: https://anaconda.org/bioconda/demuxem

.. |Python| image:: https://img.shields.io/pypi/pyversions/demuxEM.svg
   :target: https://pypi.org/project/demuxEM

.. |Docs| image:: https://readthedocs.org/projects/demuxem/badge/?version=latest
   :target: https://demuxEM.readthedocs.io

.. |License| image:: https://img.shields.io/github/license/klarman-cell-observatory/demuxEM
   :target: https://github.com/klarman-cell-observatory/demuxEM/blob/master/LICENSE

demuxEM is the demultiplexing module of Pegasus.

`Read documentation <https://demuxEM.readthedocs.io>`__
